==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/table/lang/sk.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'table', 'sk', {
	border: 'Šírka rámu (border)',
	caption: 'Popis',
	cell: {
		menu: 'Bunka',
		insertBefore: 'Vložiť bunku pred',
		insertAfter: 'Vložiť bunku za',
		deleteCell: 'Vymazať bunky',
		merge: 'Zlúčiť bunky',
		mergeRight: 'Zlúčiť doprava',
		mergeDown: 'Zlúčiť dole',
		splitHorizontal: 'Rozdeliť bunky horizontálne',
		splitVertical: 'Rozdeliť bunky vertikálne',
		title: 'Vlastnosti bunky',
		cellType: 'Typ bunky',
		rowSpan: 'Rozsah riadkov',
		colSpan: 'Rozsah stĺpcov',
		wordWrap: 'Zalomovanie riadkov',
		hAlign: 'Horizontálne zarovnanie',
		vAlign: 'Vertikálne zarovnanie',
		alignBaseline: 'Základná čiara (baseline)',
		bgColor: 'Farba pozadia',
		borderColor: 'Farba rámu',
		data: 'Dáta',
		header: 'Hlavička',
		yes: 'Áno',
		no: 'Nie',
		invalidWidth: 'Šírka bunky musí byť číslo.',
		invalidHeight: 'Výška bunky musí byť číslo.',
		invalidRowSpan: 'Rozsah riadkov musí byť celé číslo.',
		invalidColSpan: 'Rozsah stĺpcov musí byť celé číslo.',
		chooseColor: 'Vybrať'
	},
	cellPad: 'Odsadenie obsahu (cell padding)',
	cellSpace: 'Vzdialenosť buniek (cell spacing)',
	column: {
		menu: 'Stĺpec',
		insertBefore: 'Vložiť stĺpec pred',
		insertAfter: 'Vložiť stĺpec po',
		deleteColumn: 'Zmazať stĺpce'
	},
	columns: 'Stĺpce',
	deleteTable: 'Vymazať tabuľku',
	headers: 'Hlavička',
	headersBoth: 'Obe',
	headersColumn: 'Prvý stĺpec',
	headersNone: 'Žiadne',
	headersRow: 'Prvý riadok',
	invalidBorder: 'Širka rámu musí byť číslo.',
	invalidCellPadding: 'Odsadenie v bunkách (cell padding) musí byť kladné číslo.',
	invalidCellSpacing: 'Medzera mädzi bunkami (cell spacing) musí byť kladné číslo.',
	invalidCols: 'Počet stĺpcov musí byť číslo väčšie ako 0.',
	invalidHeight: 'Výška tabuľky musí byť číslo.',
	invalidRows: 'Počet riadkov musí byť číslo väčšie ako 0.',
	invalidWidth: 'Širka tabuľky musí byť číslo.',
	menu: 'Vlastnosti tabuľky',
	row: {
		menu: 'Riadok',
		insertBefore: 'Vložiť riadok pred',
		insertAfter: 'Vložiť riadok po',
		deleteRow: 'Vymazať riadky'
	},
	rows: 'Riadky',
	summary: 'Prehľad',
	title: 'Vlastnosti tabuľky',
	toolbar: 'Tabuľka',
	widthPc: 'percent',
	widthPx: 'pixelov',
	widthUnit: 'jednotka šírky'
} );

==> request-tracker5_5.0.7+dfsg.orig-third-party-source.tar.gz: rt-5.0.7/devel/third-party/ckeditor-src/plugins/table/lang/sk.js <==
/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'sk', {
	border: 'Šírka orámovania',
	caption: 'Popis',
	cell: {
		menu: 'Bunka',
		insertBefore: 'Vložiť bunku pred',
		insertAfter: 'Vložiť bunku za',
		deleteCell: 'Vymazať bunky',
		merge: 'Zlúčiť bunky',
		mergeRight: 'Zlúčiť doprava',
		mergeDown: 'Zlúčiť dole',
		splitHorizontal: 'Rozdeliť bunky horizontálne',
		splitVertical: 'Rozdeliť bunky vertikálne',
		title: 'Vlastnosti bunky',
		cellType: 'Typ bunky',
		rowSpan: 'Rozsah riadkov',
		colSpan: 'Rozsah stĺpcov',
		wordWrap: 'Zalamovanie riadkov',
		hAlign: 'Horizontálne zarovnanie',
		vAlign: 'Vertikálne zarovnanie',
		alignBaseline: 'Základná čiara (baseline)',
		bgColor: 'Farba pozadia',
		borderColor: 'Farba orámovania',
		data: 'Dáta',
		header: 'Hlavička',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Áno',
		no: 'Nie',
		invalidWidth: 'Šírka bunky musí byť číslo.',
		invalidHeight: 'Výška bunky musí byť číslo.',
		invalidRowSpan: 'Rozsah riadkov musí byť celé číslo.',
		invalidColSpan: 'Rozsah stĺpcov musí byť celé číslo.',
		chooseColor: 'Vybrať'
	},
	cellPad: 'Odsadenie obsahu (cell padding)',
	cellSpace: 'Vzdialenosť buniek (cell spacing)',
	column: {
		menu: 'Stĺpec',
		insertBefore: 'Vložiť stĺpec pred',
		insertAfter: 'Vložiť stĺpec po',
		deleteColumn: 'Zmazať stĺpce'
	},
	columns: 'Stĺpce',
	deleteTable: 'Vymazať tabuľku',
	headers: 'Hlavička',
	headersBoth: 'Obe',
	headersColumn: 'Prvý stĺpec',
	headersNone: 'Žiadne',
	headersRow: 'Prvý riadok',
	heightUnit: 'jednotka výšky',
	invalidBorder: 'Šírka orámovania musí byť číslo.',
	invalidCellPadding: 'Odsadenie v bunkách (cell padding) musí byť kladné číslo.',
	invalidCellSpacing: 'Medzera mädzi bunkami (cell spacing) musí byť kladné číslo.',
	invalidCols: 'Počet stĺpcov musí byť číslo väčšie ako 0.',
	invalidHeight: 'Výška tabuľky musí byť číslo.',
	invalidRows: 'Počet riadkov musí byť číslo väčšie ako 0.',
	invalidWidth: 'Širka tabuľky musí byť číslo.',
	menu: 'Vlastnosti tabuľky',
	row: {
		menu: 'Riadok',
		insertBefore: 'Vložiť riadok pred',
		insertAfter: 'Vložiť riadok po',
		deleteRow: 'Vymazať riadky'
	},
	rows: 'Riadky',
	summary: 'Prehľad',
	title: 'Vlastnosti tabuľky',
	toolbar: 'Tabuľka',
	widthPc: 'percent',
	widthPx: 'pixelov',
	widthUnit: 'jednotka šírky'
} );
